@@ -310,6 +310,18 @@ class DefaultEmitter(Emitter):
             + "\n"
         )
 
+    def emit_entity(self, entity: Entity):
+        self.__write_entity(entity)
+    
+    def emit_asset(self, asset: Asset):
+        return self.__write_asset(asset)
+    
+    def emit_relationship(self, relationship: Relationship):
+        return self.__write_relationship(relationship)
+    
+    def emit_error(self, err: Error):
+        return self.__write_error(err)
+    
     def emit_entities(self, entities: typing.List[Entity]):
         if entities is None or len(entities) <= 0:
             raise ValueError("Entities cannot be null or empty.")
